/* 

                          Firewall Builder

                 Copyright (C) 2003 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: DialogFactory.h,v 1.2.4.1 2005/10/25 06:11:26 vkurland Exp $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include <qwidget.h>

namespace libfwbuilder {
    class FWObject;
    class FWException;
};

class DialogFactory {

 public:

    static QWidget *createDialog(QWidget *parent,const QString &objType);
    static QWidget *createFWDialog(QWidget *parent,libfwbuilder::FWObject *o)
        throw(libfwbuilder::FWException);
    static QWidget *createOSDialog(QWidget *parent,libfwbuilder::FWObject *o)
        throw(libfwbuilder::FWException);
    
};
